@@ -1,6 +1,6 @@
 
 
-def nestedPrintList(anyList, nestedLevel):
+def nestedPrintList(anyList, nestedLevel=0):
 
     for eachItem in anyList:
 
